

attribute vec4 aPosition;

uniform mat4  matrix_viewProjection;
uniform mat4  matrix_model;
uniform mat4  matrix_view;


uniform float uTime;


varying vec4 outColor;

void main(void)
{
    // Transform the geometry
    mat4 modelView = matrix_view * matrix_model;
    mat4 modelViewProj = matrix_viewProjection * matrix_model;
    gl_Position = modelViewProj * aPosition;

    // vertex in world space
    vec4 vertexWorld = matrix_model * aPosition;

    // use sine way to generate intensity value based on time and also y-coordinate of model
    float intensity = abs(sin(0.2 * vertexWorld.y + uTime * 1.0));

    // intensity smoothly drops to zero for smaller values than 0.9
    intensity = smoothstep(0.9, 1.0, intensity);

    // point size depends on intensity
    gl_PointSize = clamp(4.0 * intensity, 1.0, 64.0);

    // color mixes red and yellow based on intensity
    outColor = mix(vec4(1.0, 1.0, 0.0, 1.0), vec4(0.9, 1.0, 0.0, 1.0), intensity);
}